@@ -4,7 +4,8 @@ from vinca._lib import ansi
 from vinca._lib.readkey import readkey
 from vinca._lib.julianday import today
 
-class Cardlist:
+class Cardlist(list):
+        ''
         ''' A Cardlist is basically just an SQL query linked to a database
         The filter, sort, findall, and slice methods build up this query
         When used as an iterator it is just a list of cards (ids) 
@@ -16,12 +17,21 @@ class Cardlist:
                 self._conditions = conditions
                 self._ORDER_BY = ORDER_BY
 
+        # overwrite __dir__ so that we fool python FIRE
+        # we don't want methods inherited from list
+        # to show up in our help message
+        def __dir__(self):
+                members = super().__dir__()
+                hidden = ['extend','index','pop','mro','remove','append',
+                          'clear','insert','reverse','copy']
+                return [m for m in members if m not in hidden]
+
         def _copy(self):
                 # create a copy of the conditions list obejct (lists are mutable!)
                 # we don't want to be affected by subsequent changes to conditions
                 return self.__class__(
                         self._cursor,
-                        [c for c in self._conditions],
+                        self._conditions.copy(),
                         self._ORDER_BY)
 
         @property
@@ -91,7 +101,7 @@ class Cardlist:
         def tags(self):
                 ' all tags in this cardlist '
                 self._cursor.execute(f'SELECT tag FROM tags JOIN '
-                    '({self._SELECT_IDS}) ON tags.card_id=id GROUP BY tag')
+                    f'({self._SELECT_IDS}) ON tags.card_id=id GROUP BY tag')
                 return [row[0] for row in self._cursor.fetchall()]
 
         def count(self):
@@ -186,7 +196,8 @@ class Cardlist:
                 ''' total time spend studying these cards '''
                 self._cursor.execute(f'SELECT sum(seconds) FROM ({self._SELECT_IDS})'
                         ' LEFT JOIN reviews ON id=card_id')
-                return self._cursor.fetchone()[0]
+                hours = self._cursor.fetchone()[0] // 3600
+                return f'{hours} hours'
 
         def _make_basic_card(self):
                 ' make a basic question and answer flashcard '
